==> haskell-template-haskell-compat-v0208-0.1.7-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-template-haskell-compat-v0208.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 template-haskell-compat-v0208
version:              0.1.7
visibility:           public
id:                   template-haskell-compat-v0208-0.1.7-6exjcgHm7B1DXkdsfJGPwL
key:                  template-haskell-compat-v0208-0.1.7-6exjcgHm7B1DXkdsfJGPwL
license:              MIT
copyright:            (c) 2016, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:
    https://github.com/nikita-volkov/template-haskell-compat-v0208

synopsis:
    A backwards compatibility layer for Template Haskell newer than 2.8

category:             TemplateHaskell, Compatibility
abi:                  f315e264180f28951a827511c363e449
exposed:              True
exposed-modules:      TemplateHaskell.Compat.V0208
hidden-modules:       TemplateHaskell.Compat.V0208.Prelude
import-dirs:
    /usr/lib/ghc-9.0.1/site-local/template-haskell-compat-v0208-0.1.7

library-dirs:
    /usr/lib/ghc-9.0.1/site-local/template-haskell-compat-v0208-0.1.7

dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.1/template-haskell-compat-v0208-0.1.7

hs-libraries:
    HStemplate-haskell-compat-v0208-0.1.7-6exjcgHm7B1DXkdsfJGPwL

depends:              base-4.15.0.0 template-haskell-2.17.0.0
haddock-interfaces:
    /usr/share/doc/haskell-template-haskell-compat-v0208/html/template-haskell-compat-v0208.haddock

haddock-html:         /usr/share/doc/haskell-template-haskell-compat-v0208/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-template-haskell-compat-v0208-0.1.9.1-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-template-haskell-compat-v0208.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 template-haskell-compat-v0208
version:              0.1.9.1
visibility:           public
id:
    template-haskell-compat-v0208-0.1.9.1-7l0MVNX5ZP87vABkCF62xQ

key:
    template-haskell-compat-v0208-0.1.9.1-7l0MVNX5ZP87vABkCF62xQ

license:              MIT
copyright:            (c) 2016, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:
    https://github.com/nikita-volkov/template-haskell-compat-v0208

synopsis:
    A backwards compatibility layer for Template Haskell newer than 2.8

category:             TemplateHaskell, Compatibility
abi:                  3e3c479d3438b68bb59f7a5122e8dffb
exposed:              True
exposed-modules:      TemplateHaskell.Compat.V0208
hidden-modules:       TemplateHaskell.Compat.V0208.Prelude
import-dirs:
    /usr/lib/ghc-9.0.2/site-local/template-haskell-compat-v0208-0.1.9.1

library-dirs:
    /usr/lib/ghc-9.0.2/site-local/template-haskell-compat-v0208-0.1.9.1

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-template-haskell-compat-v0208
hs-libraries:
    HStemplate-haskell-compat-v0208-0.1.9.1-7l0MVNX5ZP87vABkCF62xQ

depends:              base-4.15.1.0 template-haskell-2.17.0.0
haddock-interfaces:
    /usr/share/doc/haskell-template-haskell-compat-v0208/html/template-haskell-compat-v0208.haddock

haddock-html:         /usr/share/doc/haskell-template-haskell-compat-v0208/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
